@@ -4,13 +4,15 @@ use warnings;
 use strict;
 use feature 'say';
 
-use Carp qw(croak);
+use Carp qw(croak confess);
+use Data::Dumper;
 use Exporter qw(import);
 use File::Path qw(make_path);
 use File::Temp qw(tempdir);
+use Module::Installed::Tiny qw(module_installed);
 use PPI;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub new {
     my ($class, %p) = @_;
@@ -41,13 +43,14 @@ sub check {
             next;
         }
 
+        next if $module eq 'Carp';
         $module =~ s|::|/|g;
         if (my ($dir, $file) = $module =~ m|^(.*)/(.*)$|) {
             $file .= '.pm';
             my $path = "$dir/$file";
 
-            if (exists $INC{$path}) {
-                # Skip includes that are actually available
+            if (module_installed($package)) {
+                # Skip includes that are actually installed
                 say "Skipping available module '$package'" if $self->{verbose};
                 next;
             }
@@ -81,7 +84,13 @@ sub check {
         }
     }
 
-    `perl -I$self->{lib} -c $self->{file}`;
+
+    if (! $self->{lib}) {
+        `perl -c $self->{file}`;
+    }
+    else {
+        `perl -I$self->{lib} -c $self->{file}`;
+    }
 }
 sub _create_lib_dir {
     my ($self) = @_;
@@ -115,7 +124,7 @@ file are not available to the file.
 
 Binary:
 
-    ./syncheck [--verbose] [--keep] perl_filename.ext
+    syncheck [--verbose] [--keep] perl_filename.ext
 
 Library:
 
@@ -129,7 +138,7 @@ Installed with this library is a binary application that uses the library.
 
 Usage:
 
-    ./syncheck [-k] [-v] perl_file_name.ext
+    syncheck [-k] [-v] perl_file_name.ext
 
 =head2 --keep|-k
 
@@ -140,6 +149,10 @@ temp dir. By default we delete this directory upon program completion.
 
 Supply this argument to get verbose output.
 
+=head2 perl_file.ext
+
+This argument is mandatory, and must follow all others. It's the file you want
+to perform syntax checking on.
 
 =head1 METHODS
 
